class bi_elasticsearch::conf::elasticsearch (
    $cluster_name = hiera("cluster_name", undef),
    $node_name = hiera("node_name", undef),
    $path_data = hiera("path_data", undef),
    $path_work = hiera("path_work", undef),
    $discovery_zen_minimum_master_nodes = hiera("discovery_zen_minimum_master_nodes", undef),
    $discovery_zen_ping_multicast_enabled = hiera("discovery_zen_ping_multicast_enabled", undef),
    $discovery_zen_ping_unicast_hosts = hiera("discovery_zen_ping_unicast_hosts", undef),
    $http_port = hiera("http_port", undef),
) {
    require ::bi_banner
    require ::bi_elasticsearch
    
    $path = "$bi_elasticsearch::etc_dir/elasticsearch.yml"
    
    if $cluster_name == undef or !is_string($cluster_name) { 
        fail("'cluster_name' must be defined") 
    }
    
    if $node_name == undef or !is_string($node_name) { 
        fail("'node_name' must be defined") 
    }
    
    if $path_data == undef or !is_string($path_data) { 
        fail("'path_data' must be defined") 
    }
    
    if $path_work == undef or !is_string($path_work) { 
        fail("'path_work' must be defined") 
    }
    
    if $http_port == undef or !is_numeric($http_port) { 
        fail("'http_port' must be defined and a number") 
    }
    
    if $discovery_zen_minimum_master_nodes == undef or !is_numeric($discovery_zen_minimum_master_nodes) { 
        fail("'discovery_zen_minimum_master_nodes' must be defined and a number") 
    }
    
    if $discovery_zen_ping_multicast_enabled == undef or !is_bool($discovery_zen_ping_multicast_enabled) { 
        fail("'discovery_zen_ping_multicast_enabled' must be defined and a number") 
    }
    
    if $discovery_zen_ping_unicast_hosts != undef and is_array($discovery_zen_ping_unicast_hosts) {
        $real_discovery_zen_ping_unicast_hosts = join($discovery_zen_ping_unicast_hosts, ",")
    } else {
        $real_discovery_zen_ping_unicast_hosts = undef
    }
    
    file { $path:
        owner => 'root',
        group => 'root',
        mode => '644',
        ensure => present,
        content => template("$::bi_banner::pound_header", "$module_name/etc/elasticsearch/elasticsearch.yml.erb"),
        notify => Class[::bi_elasticsearch::server::service],
    }
}

