define bi_elasticsearch::server::snapshot (
  $backup_name = $title,
  $interval = 'daily',
  $backup_dir = undef,
  $manage_backup_dir = false,
  $host = 'localhost',
  $port = 9200,
  $compressed = true,
  $ensure = 'present',
  $owner = 'elasticsearch',
  $group = 'elasticsearch',
  $tries = 10,
  $try_sleep = 2,
) {
    
    if $backup_name == undef or !is_string($backup_name) { 
        fail("'backup_name' must be defined") 
    }
    
    if $owner == undef or !is_string($owner) { 
        fail("'owner' must be defined") 
    }
    
    if $group == undef or !is_string($group) { 
        fail("'group' must be defined") 
    }
    
    if $interval == undef or !is_string($interval) { 
        fail("'interval' must be defined") 
    }
    
    if $backup_dir == undef or !is_string($backup_dir) { 
        fail("'backup_dir' must be defined") 
    }
    
    if $manage_backup_dir == undef or !is_bool($manage_backup_dir) { 
        fail("'manage_backup_dir' must be defined and a boolean") 
    }
    
    if $host == undef or !is_string($host) { 
        fail("'host' must be defined") 
    }
    
    if $port == undef or !is_numeric($port) { 
        fail("'port' must be defined") 
    }
    
    if $compressed == undef or !is_bool($compressed) { 
        fail("'compressed' must be defined") 
    }
    
    if $ensure == undef or !is_string($ensure) { 
        fail("'ensure' must be defined") 
    }
    
    include ::bi_elasticsearch
    include ::bi_elasticsearch::server
    include ::bi_cron
    include ::bi_curl # for templates
  
    $json = "$bi_elasticsearch::etc_dir/snapshot-config.json"
    $config_check_script = "$bi_elasticsearch::etc_dir/snapshot-config-check.bash"
    $config_register_script = "$bi_elasticsearch::etc_dir/snapshot-config-register.bash"
    $config_unregister_script = "$bi_elasticsearch::etc_dir/snapshot-config-unregister.bash"
    $execute_script = "$bi_elasticsearch::etc_dir/snapshot-execute.bash"
    $cron_script = "elasticsearch-backup-$backup_name"
    
    anchor { 'bi_elasticsearch::server::snapshot::start': }
    anchor { 'bi_elasticsearch::server::snapshot::end': }
    
#    Anchor['bi_elasticsearch::server::snapshot::start'] ->
#        Class[::bi_elasticsearch] ->
#        Class[::bi_elasticsearch::server] ->
#        File[$json] ->
#        File[$backup_dir] ->
#        File[$config_check_script] ->
#        File[$config_register_script] ->
#        File[$config_unregister_script] ->
#        File[$execute_script] ->
#        Class[::bi_curl] ->
#        Exec[$config_register_script] ->
#        Class[::bi_cron]
#        Bi_cron::Interval[$cron_script] ->
#    Anchor['bi_elasticsearch::server::snapshot::end']
  
    file { $json:
        ensure => $ensure,
        owner => 'root',
        group => 'root',
        mode => '644',
        content => template("$module_name/etc/elasticsearch/snapshot-config.json.erb"),
    }
    
    if $manage_backup_dir {
        bi_coreutils::mkdir { $backup_dir:
            parents => true,
            mode => '755',
        }
        
        bi_coreutils::chown { $backup_dir:
            owner => $owner,
            group => $group,
            require => Bi_coreutils::Mkdir[$backup_dir],
        }
    }
  
    file { $config_check_script:
        ensure => $ensure,
        owner => 'root',
        group => 'root',
        mode => '755',
        content => template("$module_name/etc/elasticsearch/snapshot-config-check.bash.erb"),
    }
  
    file { $config_register_script:
        ensure => $ensure,
        owner => 'root',
        group => 'root',
        mode => '755',
        content => template("$module_name/etc/elasticsearch/snapshot-config-register.bash.erb"),
    }
  
    file { $config_unregister_script:
        ensure => $ensure,
        owner => 'root',
        group => 'root',
        mode => '755',
        content => template("$module_name/etc/elasticsearch/snapshot-config-unregister.bash.erb"),
    }
  
    file { $execute_script:
        ensure => $ensure,
        owner => 'root',
        group => 'root',
        mode => '755',
        content => template("$module_name/etc/elasticsearch/snapshot-execute.bash.erb"),
    }
  
    if $manage_backup_dir {
        exec { $config_register_script:
            unless => $config_check_script,
            tries => $tries,
            try_sleep => $try_sleep,
            require => [
                File[$json],
                File[$config_check_script],
                File[$config_register_script],
                File[$config_unregister_script],
                Bi_coreutils::Mkdir[$backup_dir],
                Bi_coreutils::Chown[$backup_dir],
                Class[::bi_elasticsearch::server],
            ],
        }
    } else {
        exec { $config_register_script:
            unless => $config_check_script,
            tries => $tries,
            try_sleep => $try_sleep,
            require => [
                File[$json],
                File[$config_check_script],
                File[$config_register_script],
                File[$config_unregister_script],
                Class[::bi_elasticsearch::server],
            ],
        }
    }
  
    bi_cron::interval { $cron_script:
        interval => $interval,
        content => template("$module_name/etc/cron.d/es-snapshot.erb"),
        require => [
            Exec[$config_register_script],
            Class[::bi_cron],
        ],
    }
}